/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "assert/assert.h"
#include "render.h"
#include "term.h"
#include "rpg/entity/entity.h"

void renderInit() {
  termInit();
}

void renderUpdate() {
  char_t c;
  color_t color, colorCurrent;
  entity_t *ent;

  termUpdate();
  termClear();

  colorCurrent = COLOR_WHITE;
  termPushColor(colorCurrent);

  for(int32_t y = 0; y < TERM.height; y++) {
    for(int32_t x = 0; x < TERM.width; x++) {
      color = COLOR_WHITE;
      c = ' ';

      ent = entityGetAt(x, y);
      if(ent) {
        color = COLOR_RED;
        
        switch(ent->dir) {
          case ENTITY_DIR_UP:
            c = '^';
            color = COLOR_GREEN;
            break;
          case ENTITY_DIR_DOWN:
            c = 'v';
            color = COLOR_RED;
            break;
          case ENTITY_DIR_LEFT:
            c = '<';
            color = COLOR_YELLOW;
            break;
          case ENTITY_DIR_RIGHT:
            c = '>';
            color = COLOR_BLUE;
            break;
          default:
            assertUnreachable("Invalid entity direction");
            break;
        }
      }

      if(c == ' ') {
        termPushChar(' ');
        continue;
      }

      if(color != colorCurrent) termPushColor((colorCurrent = color));
      termPushChar(c);
    }
  }

  termFlush();
}