/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "assert/assert.h"
#include "term.h"
#include "util/memory.h"
#include <sys/ioctl.h>

term_t TERM;

const char_t* TERM_COLORS[COLOR_COUNT] = {
  [COLOR_BLACK]   = "\033[30m",
  [COLOR_RED]     = "\033[31m",
  [COLOR_GREEN]   = "\033[32m",
  [COLOR_YELLOW]  = "\033[33m",
  [COLOR_BLUE]    = "\033[34m",
  [COLOR_MAGENTA] = "\033[35m",
  [COLOR_CYAN]    = "\033[36m",
  [COLOR_WHITE]   = "\033[37m"
};

void termInit() {
  memoryZero(&TERM, sizeof(term_t));

  struct winsize w;
  if(ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) == 0) {
    TERM.width = w.ws_col;
    TERM.height = w.ws_row;
  }
}

void termUpdate() {
  struct winsize w;
  if(ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) == 0) {
    TERM.width = w.ws_col;
    TERM.height = w.ws_row;
  }
}

void termClear() {
  printf("\033[2J\033[H");
}

void termPushColor(const color_t color) {
  assertTrue(color < COLOR_COUNT, "Invalid color index");
  printf("%s", TERM_COLORS[color]);
}

void termPushChar(const char_t c) {
  putchar(c);
}

void termFlush() {
  fflush(stdout);
}