/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dusk.h"
#include "display/color.h"

typedef struct {
  int32_t width;
  int32_t height;
} term_t;

extern term_t TERM;

extern const char_t* TERM_COLORS[COLOR_COUNT];

/**
 * Initialize the terminal system.
 */
void termInit();

/**
 * Update the terminal system, typically called each frame.
 */
void termUpdate();

/**
 * Clear the terminal screen and reset cursor position.
 */
void termClear();

void termPushColor(const color_t color);

/**
 * Push a character to the terminal output buffer.
 * 
 * @param c The character to push.
 */
void termPushChar(const char_t c);

/**
 * Flush the terminal output buffer to the terminal.
 */
void termFlush();