/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "entity.h"
#include "assert/assert.h"
#include "input.h"

void playerInit(entity_t *player) {
  assertNotNull(player, "Player entity is NULL");
  assertTrue(player->type == ENTITY_TYPE_PLAYER, "Entity is not a player");
}

void playerUpdate(entity_t *entity) {
  assertNotNull(entity, "Entity is NULL");
  assertTrue(entity->type == ENTITY_TYPE_PLAYER, "Entity is not a player");

  if(!entityIsWalking(entity)) {
    entitydir_t dir = 0xFF;
    if(inputIsDown(INPUT_UP)) {
      dir = ENTITY_DIR_UP;
    } else if(inputIsDown(INPUT_DOWN)) {
      dir = ENTITY_DIR_DOWN;
    } else if(inputIsDown(INPUT_LEFT)) {
      dir = ENTITY_DIR_LEFT;
    } else if(inputIsDown(INPUT_RIGHT)) {
      dir = ENTITY_DIR_RIGHT;
    }
    
    if(dir != 0xFF) {
      if(dir != entity->dir) {
        entityTurn(entity, dir);
      } else {
        entityWalk(entity);
      }
    }
  }

}